@@ -6,6 +6,7 @@ from rgd.serializers import (
     TASK_EVENT_READ_ONLY_FIELDS,
     ChecksumFileSerializer,
     RelatedField,
+    SpatialEntryFootprintSerializer,
     SpatialEntrySerializer,
 )
 
@@ -35,12 +36,13 @@ class FMVMetaSerializer(SpatialEntrySerializer):
         ]
 
 
-class FMVMetaDataSerializer(FMVMetaSerializer):
+class FMVMetaDataSerializer(FMVMetaSerializer, SpatialEntryFootprintSerializer):
     def to_representation(self, value):
         ret = super().to_representation(value)
         ret['ground_frames'] = json.loads(value.ground_frames.geojson)
         ret['ground_union'] = json.loads(value.ground_union.geojson)
         ret['flight_path'] = json.loads(value.flight_path.geojson)
+        ret['frame_numbers'] = value._blob_to_array(value.frame_numbers)
         return ret
 
     class Meta:
